diff --git a/scripts/start/prepare_and_run.R b/scripts/start/prepare_and_run.R
index ce92b624e180d3d14a2dd1c00cdd795761338b85..9b4c4427885a911b771eb2baacdaac44699b75c7 100644
--- a/scripts/start/prepare_and_run.R
+++ b/scripts/start/prepare_and_run.R
@@ -227,11 +227,15 @@ prepare <- function() {
   #  create_ExogSameAsPrevious_CO2price_file(as.character(cfg$files2export$start["input_ref.gdx"]))
   #}  
   
-  # select demand pathway for transportation: options are conv (conventional demand pathway) and wise (wiseways, limited demand)
-  if(grepl("Wise", cfg$gms$cm_EDGEtr_scen)){
-  demTrsp = "wise"
-  } else {
-  demTrsp = "conv"
+  # select demand pathway for transportation when using the EDGE-T model: options are conv (conventional demand pathway) and wise (wiseways, limited demand)
+  if(transport == "edge_esm"){
+
+    if(grepl("Wise", cfg$gms$cm_EDGEtr_scen)){
+       demTrsp = "wise"
+    } else {
+       demTrsp = "conv"
+    }
+
   }
 
   # Calculate CES configuration string
@@ -242,7 +246,7 @@ prepare <- function() {
                                          "POP_", cfg$gms$cm_POPscen, "-",
                                          "GDP_", cfg$gms$cm_GDPscen, "-",
                                          "Kap_", cfg$gms$capitalMarket, "-",
-                                         "demTrsp_", demTrsp, "-",
+                                         ifelse(transport == "edge_esm", paste0( "demTrsp_", demTrsp, "-"), ""),
                                          "Reg_", substr(regionscode(cfg$regionmapping),1,10))
   
   # write name of corresponding CES file to datainput.gms